@@ -1103,8 +1103,9 @@ class account():
                     print "trying third format"
                     msgDate = datetime.datetime.strptime(strippedDate, "%a %b %d %H:%M:%S +0000 %Y")
                 except ValueError, e:
-                    print e
-                    print "returning datestamp for now"
+                    print e 
+                    print "returning datestamp for now failed to parse >" + timestr + "<"
+                    print "expected something in the form >Thu Aug 26 12:00:00 +0000 2010<"
                     return datetime.datetime.today()
 
         timestamp = msgDate.time()
