@@ -1669,7 +1669,7 @@ class Api(object):
       parameters['since_id'] = since_id
     if max_id:
       parameters['max_id'] = max_id
-    if since_id:
+    if count:
       parameters['count'] = count
     if page:
       parameters['page'] = page
@@ -1754,7 +1754,7 @@ class Api(object):
     self._CheckForTwitterError(data)
     return User.NewFromJsonDict(data)
 
-  def GetDirectMessages(self, since=None, since_id=None, page=None):
+  def GetDirectMessages(self, since=None, since_id=None, page=None,max_id=None,count=None):
     '''Returns a list of the direct messages sent to the authenticating user.
 
     The twitter.Api instance must be authenticated.
@@ -1778,6 +1778,10 @@ class Api(object):
       parameters['since'] = since
     if since_id:
       parameters['since_id'] = since_id
+    if max_id:
+      parameters['max_id'] = max_id
+    if count:
+      parameters['count'] = count
     if page:
       parameters['page'] = page
     json = self._FetchUrl(url, parameters=parameters)
