@@ -74,7 +74,7 @@ class Witter():
     #first an init method to set everything up    
     def __init__(self):
         #version of witter
-        self.version = "0.3.1"
+        self.version = "0.3.3"
         #object holding witter config
         self.config = None
         #defaults for auto-refresh
@@ -161,6 +161,12 @@ class Witter():
                 additional_acc = account.account(self.osso_c, acc, self)
                 self.accounts.append(additional_acc)
 
+        #reload any cached tweets
+        self.activeAccount.tweetstore = self.reload_timeline_data('/home/user/.wittertl',self.activeAccount.getTimeline())
+        self.activeAccount.mentionstore = self.reload_timeline_data('/home/user/.wittermen',self.activeAccount.getMentionsList())
+        self.activeAccount.dmstore = self.reload_timeline_data('/home/user/.witterdm',self.activeAccount.getDmsList())
+        
+
         #call the refresh thread
 
         #pass the witter ui a reference to this object for callbacks
@@ -483,7 +489,7 @@ class Witter():
                 print "end of file, failed to load"
                 print e
                 self.config = None
-
+            
         except IOError:
             #couldn't find the file set uid so we can prompt
 	        #for creds
@@ -548,7 +554,81 @@ class Witter():
             print "written config object to file"
         except IOError, e:
             print "failed to write ConfigObject"
+        
+        self.save_timeline_data('/home/user/.wittertl',self.activeAccount.getTimeline())
+        self.save_timeline_data('/home/user/.wittermen',self.activeAccount.getMentionsList())
+        self.save_timeline_data('/home/user/.witterdm',self.activeAccount.getDmsList())
        
+    def save_timeline_data(self,file,store):
+        try:
+            f5 = open(file, 'w')
+            f5.write("[tweets]\n")
+            counter =0
+            item = store.get_iter_first()
+            #just store the top 20 tweets
+            while (item != None) and (counter < 20):
+                f5.write("senderName" + str(counter) + " = " + store.get_value(item,0)+"\n")
+                f5.write("senderId" + str(counter) + " = " +store.get_value(item,1)+"\n")
+                f5.write("tweet" + str(counter) + " = " + store.get_value(item, 2)+"\n")
+                #3 is unused now, used to be tweet colour
+                f5.write("tweetId" + str(counter) + " = " +str(store.get_value(item,4))+"\n")
+                f5.write("type" + str(counter)+" = " + str(store.get_value(item,5))+"\n")
+                f5.write("createdAt" + str(counter) + " = " +store.get_value(item,6)+"\n")
+                f5.write("replyTo" + str(counter) + " = " +store.get_value(item,7)+"\n")
+                f5.write("source" + str(counter) + " = " +store.get_value(item,8)+"\n")
+                #9 is avatar pic
+                f5.write("formattedTweet" + str(counter) + " = " +store.get_value(item,10)+"\n")
+                item = store.iter_next(item)
+                counter= counter+1
+                
+        except IOError, e:
+            print "failed to write timeline history file " + file
+       
+    def reload_timeline_data(self, file,tweetstore):
+        #reloads timeline/mentions/dms from files into the current active account
+        try:
+            config = ConfigParser.ConfigParser()
+            config.readfp(open(file))
+
+            counter = 0
+            while True:
+                senderName = config.get("tweets", "senderName" + str(counter));
+                senderId = config.get("tweets", "senderId" + str(counter));
+                tweet = config.get("tweets", "tweet" + str(counter));
+                tweetId = config.get("tweets", "tweetId" + str(counter));
+                tweet_long_id = float(tweetId)
+                createdAt = config.get("tweets", "createdAt" + str(counter));
+                replyTo = config.get("tweets", "replyTo" + str(counter));
+                type = config.get("tweets", "type" + str(counter));
+                source = config.get("tweets", "source" + str(counter));
+                formattedTweet = config.get("tweets", "formattedTweet" + str(counter));
+                #load avatar
+                filename = senderId+".jpg"
+                if (os.path.isfile("/home/user/.witterPics/" + self.activeAccount.accountdata.servicename + "/" + filename)):
+                    try:
+                        avatar = gtk.gdk.pixbuf_new_from_file("/home/user/.witterPics/" + self.activeAccount.accountdata.servicename + "/" + filename)
+                    except gobject.GError:
+                        #failed to load file, delete it, and go fetch a new one
+                        print "corrupted avatar file found, deleting it"
+                        os.remove("/home/user/.witterPics/" + self.accountdata.servicename + "/" + filename)
+                        print "bad file deleted, returning default icon"
+                        avatar = gtk.gdk.pixbuf_new_from_file("/opt/witter/icons/default/tweet.png")
+                    avatar = avatar.scale_simple(60, 60, gtk.gdk.INTERP_BILINEAR)
+                tweetstore.append([senderName,senderId,tweet,"",tweet_long_id,type,createdAt,replyTo,source,avatar,formattedTweet])
+                counter=counter+1
+                
+                
+        except ConfigParser.NoSectionError:
+            print "Failed to load cached timeline"
+        except ConfigParser.NoOptionError:
+            print "Failed to load cached timeline"
+        except IOError:
+            print "failed to read timeline file"
+            
+        except EOFError, e:
+            print "end of file, failed/finished? to load cached timeline"
+            print e
+        return tweetstore
 
 
     def createConfig(self):
